==> MediaWikiLanguageExtensionBundle-2012.12.tar.bz2: extensions/cldr/CldrNames/CldrNamesPt.php <==
<?php

$languageNames = array(
'af' => 'afrikaans',
'agq' => 'aghem',
'art' => 'idioma artifical',
'asa' => 'asu',
'bai' => 'bamileke Languages',
'bax' => 'bamun',
'bbj' => 'ghomala',
'bez' => 'bena',
'bfd' => 'bafut',
'bkm' => 'kom',
'bss' => 'akoose',
'bug' => 'buginese',
'bum' => 'bulu',
'byv' => 'medumba',
'cay' => 'cayuga',
'ce' => 'chechene',
'cel' => 'idioma céltico',
'cgg' => 'chiga',
'chn' => 'jargão chinook',
'ckb' => 'sorani curdo',
'co' => 'corso',
'cpe' => 'crioulo ou pidgin do inglês',
'cpf' => 'crioulo ou pidgin do francês',
'cpp' => 'crioulo ou pidgin do português',
'cs' => 'checo',
'cus' => 'idioma cuchita',
'dav' => 'taita',
'dje' => 'zarma',
'dra' => 'idioma dravítico',
'dyo' => 'jola-fonyi',
'dyu' => 'diula',
'dzg' => 'dazaga',
'ee' => 'ewe',
'egy' => 'egípcio clássico',
'enm' => 'inglês medieval',
'et' => 'estónio',
'fiu' => 'idioma ugro-finês',
'frm' => 'francês medieval',
'frs' => 'frísio oriental',
'fy' => 'frísico ocidental',
'gmh' => 'alemão medieval alto',
'grc' => 'grego clássico',
'guz' => 'gusii',
'ha' => 'haúça',
'hi' => 'hindi',
'hsb' => 'sorbiano superior',
'hy' => 'arménio',
'ibb' => 'ibibio',
'ig' => 'igbo',
'ik' => 'inupiaq',
'jmc' => 'machame',
'kbl' => 'kanembu',
'kde' => 'makonde',
'kea' => 'cabo-verdiano',
'kg' => 'conguês',
'khi' => 'khoisan',
'khq' => 'koyra chiini',
'kkj' => 'kako',
'kln' => 'kalenjin',
'kn' => 'canarim',
'ks' => 'caxemirense',
'ksb' => 'shambala',
'ksf' => 'bafia',
'lag' => 'langi',
'lez' => 'lezghiano',
'lg' => 'ganda',
'luy' => 'luyia',
'maf' => 'mafa',
'mde' => 'maba',
'mer' => 'meru',
'mfe' => 'crioulo das Ilhas Maurícias',
'mga' => 'irlandês, medieval',
'mgh' => 'makhuwa-meetto',
'mk' => 'macedónio',
'mua' => 'mundang',
'mye' => 'myene',
'nah' => 'nauatle',
'naq' => 'nama',
'nb' => 'norueguês bokmål',
'nds' => 'baixo alemão',
'nic' => 'nigeriano - cordofano',
'nmg' => 'kwasio',
'nn' => 'norueguês nynorsk',
'nnh' => 'ngiemboon',
'non' => 'norse, old',
'nus' => 'nuer',
'oc' => 'provençal',
'os' => 'ossético',
'pl' => 'polaco',
'pra' => 'idioma prácito',
'pro' => 'provençal, arcaico',
'ps' => 'pastó',
'rom' => 'romanês',
'sah' => 'sakha',
'sai' => 'idioma indígeno sul-americano',
'sal' => 'salishan languages',
'saq' => 'samburu',
'sba' => 'ngambay',
'sbp' => 'sangu',
'see' => 'seneca',
'seh' => 'sena',
'ses' => 'koyraboro senni',
'sgn' => 'linguages de sinais',
'shi' => 'tachelhit',
'shu' => 'árabe do Chade',
'ssa' => 'idioma nilo-sariano',
'ssy' => 'saho',
'swb' => 'língua comoriana',
'swc' => 'suaili do Congo',
'tai' => 'idioma tailândes',
'teo' => 'teso',
'tg' => 'tajique',
'ti' => 'tigre',
'tl' => 'tagalogue',
'to' => 'tonga',
'tog' => 'toganês',
'trv' => 'taroko',
'twq' => 'tasawaq',
'tyv' => 'tuviniano',
'tzm' => 'tamazight de Marrocos Central',
'und' => 'idioma desconhecido',
'vun' => 'vunjo',
'wen' => 'idioma sórbio',
'xog' => 'soga',
'yav' => 'yangben',
'ybb' => 'yemba',
);

$currencyNames = array(
'AED' => 'Dirham dos EmiradosÁrabes Unidos',
'AFA' => 'Afeghani (1927-2002)',
'AFN' => 'Afgani afegão',
'ALL' => 'Lek albanês',
'AMD' => 'Dram arménio',
'AOA' => 'Kwanza angolano',
'AWG' => 'Florim de Aruba',
'AZN' => 'Manat do Azerbaijão',
'BAD' => 'Dinar da Bósnia-Herzegóvina',
'BAM' => 'Marco bósnio-herzegóvino conversível',
'BDT' => 'Taka de Bangladesh',
'BEC' => 'Franco belga (convertível)',
'BHD' => 'Dinar baremita',
'BMD' => 'Dólar bermudense',
'BND' => 'Dólar bruneíno',
'BSD' => 'Dólar das Bahamas',
'BTN' => 'Ngultrum do Butão',
'BWP' => 'Pula de Botswana',
'BYB' => 'Rublo novo bielorusso (1994-1999)',
'BYR' => 'Rublo bielorusso',
'BZD' => 'Dólar belizense',
'CAD' => 'Dólar canadiano',
'CRC' => 'Colon da Costa Rica',
'CYP' => 'Libra de Chipre',
'DJF' => 'Franco jibutiano',
'ECV' => 'Unidad de Valor Constante (UVC) do Equador',
'FJD' => 'Dólar de Fiji',
'FKP' => 'Libra das Ilhas Falkland',
'GHC' => 'Cedi do Gana',
'GHS' => 'Cedi de Gana',
'GMD' => 'Dalasi da Gâmbia',
'GNF' => 'Franco Guineense',
'GTQ' => 'Quetzal da Guatemala',
'GYD' => 'Dólar da Guiana',
'HNL' => 'Lempira das Honduras',
'HTG' => 'Gurde do Haiti',
'HUF' => 'Forint húngaro',
'IDR' => 'Rupia indonésia',
'ILS' => 'Sheqel novo israelita',
'INR' => 'Rupia indiana',
'IRR' => 'Rial iraniano',
'KES' => 'Xelim queniano',
'KGS' => 'Som do Quirguistão',
'KMF' => 'Franco comoriano',
'KWD' => 'Dinar kuwaitiano',
'KYD' => 'Dólar das Ilhas Caimão',
'KZT' => 'Tenge do Cazaquistão',
'LAK' => 'Kip de Laos',
'LKR' => 'Rupia do Sri Lanka',
'LTL' => 'Litas da Lituânia',
'LVL' => 'Lats da Letónia',
'MAD' => 'Dirham marroquino',
'MDL' => 'Leu moldavo',
'MGA' => 'Ariari de Madagáscar',
'MKD' => 'Dinar macedónio',
'MLF' => 'Franco do Mali',
'MMK' => 'Kyat de Mianmar',
'MNT' => 'Tugrik da Mongólia',
'MOP' => 'Pataca macaense',
'MRO' => 'Ouguiya da Mauritânia',
'MUR' => 'Rupia mauriciana',
'MVR' => 'Rupia das Ilhas Maldivas',
'MWK' => 'Kwacha do Malawi',
'MXP' => 'Peso Plata mexicano (1861-1992)',
'MXV' => 'Unidad de Inversion (UDI) mexicana',
'MZN' => 'Metical de Moçambique',
'NAD' => 'Dólar da Namíbia',
'NGN' => 'Naira nigeriana',
'NIC' => 'Córdoba nicaraguano',
'NIO' => 'Córdoba Ouro nicaraguano',
'NPR' => 'Rupia nepalesa',
'NZD' => 'Dólar neozelandês',
'OMR' => 'Rial de Omã',
'PAB' => 'Balboa panamenho',
'PEN' => 'Novo sol peruano',
'PGK' => 'Kina da Papua-Nova Guiné',
'PKR' => 'Rupia paquistanesa',
'PLN' => 'Zloti polaco',
'PLZ' => 'Zloti polaco (1950-1995)',
'QAR' => 'Rial do Qatar',
'RON' => 'Leu romeno',
'RWF' => 'Franco ruandês',
'SAR' => 'Rial saudita',
'SCR' => 'Rupia seichelense',
'SGD' => 'Dólar de Singapura',
'SOS' => 'Xelim somali',
'SRD' => 'Dólar do Suriname',
'SSP' => 'Libra do Sudão do Sul',
'SZL' => 'Lilangeni da Suazilândia',
'THB' => 'Baht da Tailândia',
'TJS' => 'Somoni do Tajaquistão',
'TND' => 'Dinar tunisiano',
'TOP' => 'Paʻanga de Tonga',
'TTD' => 'Dólar de Trindade e Tobago',
'TZS' => 'Xelim tanzaniano',
'UAH' => 'Hryvnia da Ucrânia',
'UGX' => 'Xelim ugandense',
'USD' => 'Dólar dos Estados Unidos',
'UZS' => 'Som do Uzbequistão',
'WST' => 'Tala de Samoa Ocidental',
'XEU' => 'Unidade da Moeda Europeia',
'XXX' => 'Moeda desconhecida',
'YER' => 'Rial iemenita',
'YUD' => 'Dinar forte jugoslavo',
'YUM' => 'Super Dinar jugoslavo',
'YUN' => 'Dinar conversível jugoslavo',
'ZAR' => 'Rand sul-africano',
'ZMK' => 'Kwacha zambiano',
'ZWD' => 'Dólar do Zimbabwe',
);

$countryNames = array(
'AI' => 'Anguila',
'AM' => 'Arménia',
'AX' => 'IlhasÅland',
'BH' => 'Barém',
'BJ' => 'Benim',
'BQ' => 'Países Baixos Caribenhos',
'BY' => 'Bielorrússia',
'CC' => 'Ilhas Cocos',
'CG' => 'Congo-Brazzaville',
'CM' => 'Camarões',
'CW' => 'Curaçau',
'CX' => 'Ilha do Natal',
'CZ' => 'República Checa',
'DJ' => 'Jibuti',
'DM' => 'Domínica',
'EE' => 'Estónia',
'EG' => 'Egipto',
'FK' => 'Ilhas Falkland',
'FO' => 'Ilhas Faroé',
'GL' => 'Gronelândia',
'GU' => 'Guame',
'GW' => 'Guiné-Bissau',
'HK' => 'Região Administrativa Especial de Hong Kong',
'IR' => 'Irão',
'KE' => 'Quénia',
'KG' => 'Quirguizistão',
'KN' => 'São Cristóvão e Neves',
'KY' => 'Ilhas Caimão',
'KZ' => 'Cazaquistão',
'LV' => 'Letónia',
'MC' => 'Mónaco',
'MG' => 'Madagáscar',
'MK' => 'Macedónia',
'MO' => 'Região Administrativa Especial de Macau',
'MS' => 'Monserrate',
'MU' => 'Maurícias',
'NC' => 'Nova Caledónia',
'NL' => 'Países Baixos',
'PG' => 'Papuásia-Nova Guiné',
'PL' => 'Polónia',
'PN' => 'Pitcairn',
'PS' => 'Território Palestiniano',
'QO' => 'Oceânia Insular',
'RO' => 'Roménia',
'SC' => 'Seicheles',
'SG' => 'Singapura',
'SI' => 'Eslovénia',
'SM' => 'São Marino',
'TC' => 'Ilhas Turcas e Caicos',
'TJ' => 'Tajiquistão',
'TM' => 'Turquemenistão',
'TT' => 'Trindade e Tobago',
'UZ' => 'Usbequistão',
'VN' => 'Vietname',
'YE' => 'Iémen',
'YT' => 'Maiote',
'ZW' => 'Zimbabué',
);

==> MediaWikiLanguageExtensionBundle-2013.05.tar.bz2: extensions/cldr/CldrNames/CldrNamesPt.php <==
<?php

$languageNames = array(
'af' => 'afrikaans',
'agq' => 'aghem',
'art' => 'idioma artifical',
'asa' => 'asu',
'bai' => 'bamileke Languages',
'bax' => 'bamun',
'bbj' => 'ghomala',
'bez' => 'bena',
'bfd' => 'bafut',
'bkm' => 'kom',
'bss' => 'akoose',
'bug' => 'buginese',
'bum' => 'bulu',
'byv' => 'medumba',
'cay' => 'cayuga',
'ce' => 'chechene',
'cel' => 'idioma céltico',
'cgg' => 'chiga',
'chn' => 'jargão chinook',
'ckb' => 'sorani curdo',
'co' => 'corso',
'cpe' => 'crioulo ou pidgin do inglês',
'cpf' => 'crioulo ou pidgin do francês',
'cpp' => 'crioulo ou pidgin do português',
'cs' => 'checo',
'cus' => 'idioma cuchita',
'dav' => 'taita',
'dje' => 'zarma',
'dra' => 'idioma dravítico',
'dyo' => 'jola-fonyi',
'dyu' => 'diula',
'dzg' => 'dazaga',
'ee' => 'ewe',
'egy' => 'egípcio clássico',
'enm' => 'inglês medieval',
'et' => 'estónio',
'fiu' => 'idioma ugro-finês',
'frm' => 'francês medieval',
'frs' => 'frísio oriental',
'fy' => 'frísico ocidental',
'gmh' => 'alemão medieval alto',
'grc' => 'grego clássico',
'guz' => 'gusii',
'ha' => 'haúça',
'hi' => 'hindi',
'hsb' => 'sorbiano superior',
'hy' => 'arménio',
'ibb' => 'ibibio',
'ig' => 'igbo',
'ik' => 'inupiaq',
'jmc' => 'machame',
'kbl' => 'kanembu',
'kde' => 'makonde',
'kea' => 'cabo-verdiano',
'kg' => 'conguês',
'khi' => 'khoisan',
'khq' => 'koyra chiini',
'kkj' => 'kako',
'kln' => 'kalenjin',
'kn' => 'canarim',
'ks' => 'caxemirense',
'ksb' => 'shambala',
'ksf' => 'bafia',
'lag' => 'langi',
'lez' => 'lezghiano',
'lg' => 'ganda',
'luy' => 'luyia',
'maf' => 'mafa',
'mde' => 'maba',
'mer' => 'meru',
'mfe' => 'crioulo das Ilhas Maurícias',
'mga' => 'irlandês, medieval',
'mgh' => 'makhuwa-meetto',
'mk' => 'macedónio',
'mua' => 'mundang',
'mye' => 'myene',
'nah' => 'nauatle',
'naq' => 'nama',
'nb' => 'norueguês bokmål',
'nds' => 'baixo alemão',
'nic' => 'nigeriano - cordofano',
'nmg' => 'kwasio',
'nn' => 'norueguês nynorsk',
'nnh' => 'ngiemboon',
'non' => 'norse, old',
'nus' => 'nuer',
'oc' => 'provençal',
'os' => 'ossético',
'pl' => 'polaco',
'pra' => 'idioma prácito',
'pro' => 'provençal, arcaico',
'ps' => 'pastó',
'rom' => 'romanês',
'sah' => 'sakha',
'sai' => 'idioma indígeno sul-americano',
'sal' => 'salishan languages',
'saq' => 'samburu',
'sba' => 'ngambay',
'sbp' => 'sangu',
'see' => 'seneca',
'seh' => 'sena',
'ses' => 'koyraboro senni',
'sgn' => 'linguages de sinais',
'shi' => 'tachelhit',
'shu' => 'árabe do Chade',
'ssa' => 'idioma nilo-sariano',
'ssy' => 'saho',
'swb' => 'língua comoriana',
'swc' => 'suaili do Congo',
'tai' => 'idioma tailândes',
'teo' => 'teso',
'tg' => 'tajique',
'ti' => 'tigre',
'tl' => 'tagalogue',
'to' => 'tonga',
'tog' => 'toganês',
'trv' => 'taroko',
'twq' => 'tasawaq',
'tyv' => 'tuviniano',
'tzm' => 'tamazight de Marrocos Central',
'und' => 'idioma desconhecido',
'vun' => 'vunjo',
'wen' => 'idioma sórbio',
'xog' => 'soga',
'yav' => 'yangben',
'ybb' => 'yemba',
);

$currencyNames = array(
'AED' => 'Dirham dos Emirados Árabes Unidos',
'AFA' => 'Afeghani (1927-2002)',
'AFN' => 'Afgani afegão',
'ALL' => 'Lek albanês',
'AMD' => 'Dram arménio',
'AOA' => 'Kwanza angolano',
'AWG' => 'Florim de Aruba',
'AZN' => 'Manat do Azerbaijão',
'BAD' => 'Dinar da Bósnia-Herzegóvina',
'BAM' => 'Marco bósnio-herzegóvino conversível',
'BDT' => 'Taka de Bangladesh',
'BEC' => 'Franco belga (convertível)',
'BHD' => 'Dinar baremita',
'BMD' => 'Dólar bermudense',
'BND' => 'Dólar bruneíno',
'BSD' => 'Dólar das Bahamas',
'BTN' => 'Ngultrum do Butão',
'BWP' => 'Pula de Botswana',
'BYB' => 'Rublo novo bielorusso (1994-1999)',
'BYR' => 'Rublo bielorusso',
'BZD' => 'Dólar belizense',
'CAD' => 'Dólar canadiano',
'CRC' => 'Colon da Costa Rica',
'CYP' => 'Libra de Chipre',
'CZK' => 'Coroa checa',
'DJF' => 'Franco jibutiano',
'ECV' => 'Unidad de Valor Constante (UVC) do Equador',
'FJD' => 'Dólar de Fiji',
'FKP' => 'Libra das Ilhas Falkland',
'GHC' => 'Cedi do Gana',
'GHS' => 'Cedi de Gana',
'GMD' => 'Dalasi da Gâmbia',
'GNF' => 'Franco Guineense',
'GTQ' => 'Quetzal da Guatemala',
'GYD' => 'Dólar da Guiana',
'HNL' => 'Lempira das Honduras',
'HTG' => 'Gurde do Haiti',
'HUF' => 'Forint húngaro',
'IDR' => 'Rupia indonésia',
'ILS' => 'Sheqel novo israelita',
'INR' => 'Rupia indiana',
'IRR' => 'Rial iraniano',
'KES' => 'Xelim queniano',
'KGS' => 'Som do Quirguistão',
'KMF' => 'Franco comoriano',
'KWD' => 'Dinar kuwaitiano',
'KYD' => 'Dólar das Ilhas Caimão',
'KZT' => 'Tenge do Cazaquistão',
'LAK' => 'Kip de Laos',
'LKR' => 'Rupia do Sri Lanka',
'LTL' => 'Litas da Lituânia',
'LVL' => 'Lats da Letónia',
'MAD' => 'Dirham marroquino',
'MDL' => 'Leu moldavo',
'MGA' => 'Ariari de Madagáscar',
'MKD' => 'Dinar macedónio',
'MLF' => 'Franco do Mali',
'MMK' => 'Kyat de Mianmar',
'MNT' => 'Tugrik da Mongólia',
'MOP' => 'Pataca macaense',
'MRO' => 'Ouguiya da Mauritânia',
'MUR' => 'Rupia mauriciana',
'MVR' => 'Rupia das Ilhas Maldivas',
'MWK' => 'Kwacha do Malawi',
'MXP' => 'Peso Plata mexicano (1861-1992)',
'MXV' => 'Unidad de Inversion (UDI) mexicana',
'MZN' => 'Metical de Moçambique',
'NAD' => 'Dólar da Namíbia',
'NGN' => 'Naira nigeriana',
'NIC' => 'Córdoba nicaraguano',
'NIO' => 'Córdoba Ouro nicaraguano',
'NPR' => 'Rupia nepalesa',
'NZD' => 'Dólar neozelandês',
'OMR' => 'Rial de Omã',
'PAB' => 'Balboa panamenho',
'PEN' => 'Novo sol peruano',
'PGK' => 'Kina da Papua-Nova Guiné',
'PKR' => 'Rupia paquistanesa',
'PLN' => 'Zloti polaco',
'PLZ' => 'Zloti polaco (1950-1995)',
'QAR' => 'Rial do Qatar',
'RON' => 'Leu romeno',
'RWF' => 'Franco ruandês',
'SAR' => 'Rial saudita',
'SCR' => 'Rupia seichelense',
'SGD' => 'Dólar de Singapura',
'SOS' => 'Xelim somali',
'SRD' => 'Dólar do Suriname',
'SSP' => 'Libra do Sudão do Sul',
'SZL' => 'Lilangeni da Suazilândia',
'THB' => 'Baht da Tailândia',
'TJS' => 'Somoni do Tajaquistão',
'TND' => 'Dinar tunisiano',
'TOP' => 'Paʻanga de Tonga',
'TTD' => 'Dólar de Trindade e Tobago',
'TZS' => 'Xelim tanzaniano',
'UAH' => 'Hryvnia da Ucrânia',
'UGX' => 'Xelim ugandense',
'USD' => 'Dólar dos Estados Unidos',
'UZS' => 'Som do Uzbequistão',
'WST' => 'Tala de Samoa Ocidental',
'XDR' => 'direito especial de saque',
'XEU' => 'Unidade da Moeda Europeia',
'XXX' => 'Moeda desconhecida',
'YER' => 'Rial iemenita',
'YUD' => 'Dinar forte jugoslavo',
'YUM' => 'Super Dinar jugoslavo',
'YUN' => 'Dinar conversível jugoslavo',
'ZAR' => 'Rand sul-africano',
'ZMK' => 'Kwacha zambiano (1968-2012)',
'ZMW' => 'Kwacha zambiano',
'ZWD' => 'Dólar do Zimbabwe',
);

$countryNames = array(
'AI' => 'Anguila',
'AM' => 'Arménia',
'AX' => 'Ilhas Åland',
'BH' => 'Barém',
'BJ' => 'Benim',
'BQ' => 'Países Baixos Caribenhos',
'BY' => 'Bielorrússia',
'CC' => 'Ilhas Cocos',
'CG' => 'Congo-Brazzaville',
'CM' => 'Camarões',
'CW' => 'Curaçau',
'CX' => 'Ilha do Natal',
'CZ' => 'República Checa',
'DJ' => 'Jibuti',
'DM' => 'Domínica',
'EE' => 'Estónia',
'EG' => 'Egipto',
'FK' => 'Ilhas Falkland',
'FO' => 'Ilhas Faroé',
'GL' => 'Gronelândia',
'GU' => 'Guame',
'GW' => 'Guiné-Bissau',
'IR' => 'Irão',
'KE' => 'Quénia',
'KG' => 'Quirguizistão',
'KN' => 'São Cristóvão e Neves',
'KY' => 'Ilhas Caimão',
'KZ' => 'Cazaquistão',
'LV' => 'Letónia',
'MC' => 'Mónaco',
'MG' => 'Madagáscar',
'MK' => 'Macedónia',
'MS' => 'Monserrate',
'MU' => 'Maurícias',
'NC' => 'Nova Caledónia',
'NL' => 'Países Baixos',
'PG' => 'Papuásia-Nova Guiné',
'PL' => 'Polónia',
'PN' => 'Pitcairn',
'PS' => 'Território Palestiniano',
'QO' => 'Oceânia Insular',
'RO' => 'Roménia',
'SC' => 'Seicheles',
'SG' => 'Singapura',
'SI' => 'Eslovénia',
'SM' => 'São Marino',
'TC' => 'Ilhas Turcas e Caicos',
'TJ' => 'Tajiquistão',
'TM' => 'Turquemenistão',
'TT' => 'Trindade e Tobago',
'VN' => 'Vietname',
'YE' => 'Iémen',
'YT' => 'Maiote',
'ZW' => 'Zimbabué',
);

$timeUnits = array(
'second-one' => '{0} segundo',
'second-other' => '{0} segundos',
);
